@@ -7,11 +7,16 @@ extern struct mouse_state g_mouse_state;
 extern int g_mission_control_active;
 extern int g_connection;
 extern void *g_workspace_context;
+extern int g_layer_below_window_level;
 
 static void window_did_receive_focus(struct window_manager *wm, struct mouse_state *ms, struct window *window)
 {
+    struct window *focused_window = window_manager_find_window(wm, wm->focused_window_id);
+    if (focused_window && focused_window != window && window_space(focused_window) == window_space(window)) {
+        window_manager_set_window_opacity(wm, focused_window, g_window_manager.normal_window_opacity);
+    }
+
     window_manager_set_window_opacity(wm, window, wm->active_window_opacity);
-    border_activate(window);
 
     if (wm->focused_window_id != window->id) {
         if (ms->ffm_window_id != window->id) {
@@ -128,6 +133,7 @@ static EVENT_HANDLER(APPLICATION_LAUNCHED)
             // This is necessary to make sure that we do not call the AX API for each modification to the tree.
             //
 
+            scripting_addition_set_layer(window->id, LAYER_BELOW);
             view_add_window_node_with_insertion_point(view, window, prev_window_id);
             window_manager_add_managed_window(&g_window_manager, window, view);
 
@@ -181,7 +187,6 @@ static EVENT_HANDLER(APPLICATION_TERMINATED)
 
     for (int i = 0; i < window_count; ++i) {
         struct window *window = window_list[i];
-        border_destroy(window);
 
         struct view *view = window_manager_find_managed_window(&g_window_manager, window);
         if (view) {
@@ -247,28 +252,19 @@ static EVENT_HANDLER(APPLICATION_FRONT_SWITCHED)
         return;
     }
 
-    event_loop_post(&g_event_loop, APPLICATION_DEACTIVATED, (void *)(intptr_t) g_process_manager.front_pid, 0);
-    event_loop_post(&g_event_loop, APPLICATION_ACTIVATED, (void *)(intptr_t) process->pid, 0);
-
     debug("%s: %s (%d)\n", __FUNCTION__, process->name, process->pid);
     g_process_manager.switch_event_time = GetCurrentEventTime();
     g_process_manager.last_front_pid = g_process_manager.front_pid;
     g_process_manager.front_pid = process->pid;
-
     event_signal_push(SIGNAL_APPLICATION_FRONT_SWITCHED, NULL);
-}
-#pragma clang diagnostic pop
-
-static EVENT_HANDLER(APPLICATION_ACTIVATED)
-{
-    struct application *application = window_manager_find_application(&g_window_manager, (pid_t)(intptr_t) context);
-    if (!application) return;
-
-    debug("%s: %s\n", __FUNCTION__, application->name);
-    event_signal_push(SIGNAL_APPLICATION_ACTIVATED, application);
 
     uint32_t application_focused_window_id = application_focused_window(application);
     if (!application_focused_window_id) {
+        struct window *focused_window = window_manager_find_window(&g_window_manager, g_window_manager.focused_window_id);
+        if (focused_window) {
+            window_manager_set_window_opacity(&g_window_manager, focused_window, g_window_manager.normal_window_opacity);
+        }
+
         g_window_manager.last_window_id = g_window_manager.focused_window_id;
         g_window_manager.focused_window_id = 0;
         g_window_manager.focused_window_psn = application->psn;
@@ -278,6 +274,11 @@ static EVENT_HANDLER(APPLICATION_ACTIVATED)
 
     struct window *window = window_manager_find_window(&g_window_manager, application_focused_window_id);
     if (!window) {
+        struct window *focused_window = window_manager_find_window(&g_window_manager, g_window_manager.focused_window_id);
+        if (focused_window) {
+            window_manager_set_window_opacity(&g_window_manager, focused_window, g_window_manager.normal_window_opacity);
+        }
+
         window_manager_add_lost_focused_event(&g_window_manager, application_focused_window_id);
         return;
     }
@@ -285,29 +286,7 @@ static EVENT_HANDLER(APPLICATION_ACTIVATED)
     window_did_receive_focus(&g_window_manager, &g_mouse_state, window);
     event_signal_push(SIGNAL_WINDOW_FOCUSED, window);
 }
-
-static EVENT_HANDLER(APPLICATION_DEACTIVATED)
-{
-    struct application *application = window_manager_find_application(&g_window_manager, (pid_t)(intptr_t) context);
-    if (!application) return;
-
-    debug("%s: %s\n", __FUNCTION__, application->name);
-    event_signal_push(SIGNAL_APPLICATION_DEACTIVATED, application);
-
-    struct window *focused_window = window_manager_find_window(&g_window_manager, application_focused_window(application));
-    if (!focused_window) return;
-
-    window_manager_set_window_opacity(&g_window_manager, focused_window, g_window_manager.normal_window_opacity);
-    border_deactivate(focused_window);
-
-    if (!window_level_is_standard(focused_window) || !window_is_standard(focused_window)) {
-        struct window *main_window = window_manager_find_window(&g_window_manager, application_main_window(application));
-        if (main_window && main_window != focused_window) {
-            window_manager_set_window_opacity(&g_window_manager, main_window, g_window_manager.normal_window_opacity);
-            border_deactivate(main_window);
-        }
-    }
-}
+#pragma clang diagnostic pop
 
 static EVENT_HANDLER(APPLICATION_VISIBLE)
 {
@@ -326,7 +305,6 @@ static EVENT_HANDLER(APPLICATION_VISIBLE)
 
     for (int i = 0; i < window_count; ++i) {
         struct window *window = window_list[i];
-        border_show(window);
 
         if (window_manager_should_manage_window(window) && !window_manager_find_managed_window(&g_window_manager, window)) {
             struct view *view = space_manager_find_view(&g_space_manager, window_space(window));
@@ -342,6 +320,7 @@ static EVENT_HANDLER(APPLICATION_VISIBLE)
             // This is necessary to make sure that we do not call the AX API for each modification to the tree.
             //
 
+            scripting_addition_set_layer(window->id, LAYER_BELOW);
             view_add_window_node_with_insertion_point(view, window, prev_window_id);
             window_manager_add_managed_window(&g_window_manager, window, view);
 
@@ -388,7 +367,6 @@ static EVENT_HANDLER(APPLICATION_HIDDEN)
 
     for (int i = 0; i < window_count; ++i) {
         struct window *window = window_list[i];
-        border_hide(window);
 
         struct view *view = window_manager_find_managed_window(&g_window_manager, window);
         if (view) {
@@ -403,6 +381,7 @@ static EVENT_HANDLER(APPLICATION_HIDDEN)
             // This is necessary to make sure that we do not call the AX API for each modification to the tree.
             //
 
+            scripting_addition_set_layer(window->id, LAYER_NORMAL);
             view_remove_window_node(view, window);
             window_manager_remove_managed_window(&g_window_manager, window->id);
             window_manager_purify_window(&g_window_manager, window);
@@ -472,7 +451,6 @@ static EVENT_HANDLER(WINDOW_DESTROYED)
     struct window *window = context;
     debug("%s: %s %d\n", __FUNCTION__, window->application->name, window->id);
     assert(!__atomic_load_n(&window->id_ptr, __ATOMIC_RELAXED));
-    border_destroy(window);
 
     struct view *view = window_manager_find_managed_window(&g_window_manager, window);
     if (view) {
@@ -511,12 +489,6 @@ static EVENT_HANDLER(WINDOW_FOCUSED)
         return;
     }
 
-    struct window *focused_window = window_manager_find_window(&g_window_manager, g_window_manager.focused_window_id);
-    if (focused_window && focused_window != window) {
-        window_manager_set_window_opacity(&g_window_manager, focused_window, g_window_manager.normal_window_opacity);
-        border_deactivate(focused_window);
-    }
-
     debug("%s: %s %d\n", __FUNCTION__, window->application->name, window->id);
     window_did_receive_focus(&g_window_manager, &g_mouse_state, window);
     event_signal_push(SIGNAL_WINDOW_FOCUSED, window);
@@ -586,9 +558,6 @@ static EVENT_HANDLER(WINDOW_RESIZED)
     window->frame = new_frame;
 
     if (!was_fullscreen && is_fullscreen) {
-        window_manager_make_window_topmost(&g_window_manager, window, false);
-        border_hide(window);
-
         struct view *view = window_manager_find_managed_window(&g_window_manager, window);
         if (view) {
             space_manager_untile_window(&g_space_manager, view, window);
@@ -602,9 +571,6 @@ static EVENT_HANDLER(WINDOW_RESIZED)
             struct view *view = space_manager_tile_window_on_space(&g_space_manager, window, window_space(window));
             window_manager_add_managed_window(&g_window_manager, window, view);
         }
-
-        border_show(window);
-        window_manager_make_window_topmost(&g_window_manager, window, window_check_flag(window, WINDOW_FLOAT));
     } else if (!was_fullscreen == !is_fullscreen) {
         if (g_mouse_state.current_action == MOUSE_MODE_MOVE && g_mouse_state.window == window) {
             g_mouse_state.window_frame.size = g_mouse_state.window->frame.size;
@@ -623,7 +589,6 @@ static EVENT_HANDLER(WINDOW_MINIMIZED)
 
     debug("%s: %s %d\n", __FUNCTION__, window->application->name, window->id);
     window_set_flag(window, WINDOW_MINIMIZE);
-    border_hide(window);
 
     if (window->id == g_window_manager.last_window_id) {
         g_window_manager.last_window_id = g_window_manager.focused_window_id;
@@ -654,10 +619,6 @@ static EVENT_HANDLER(WINDOW_DEMINIMIZED)
     uint64_t sid = space_manager_active_space();
     if (space_manager_is_window_on_space(sid, window)) {
         debug("%s: window %s %d is deminimized on active space\n", __FUNCTION__, window->application->name, window->id);
-        if (window->border.id && border_should_order_in(window)) {
-            border_ensure_same_space(window);
-            SLSOrderWindow(g_connection, window->border.id, -1, window->id);
-        }
         if (window_manager_should_manage_window(window) && !window_manager_find_managed_window(&g_window_manager, window)) {
             struct window *last_window = window_manager_find_window(&g_window_manager, g_window_manager.last_window_id);
             uint32_t insertion_point = last_window && last_window->application->pid != window->application->pid ? last_window->id : 0;
@@ -691,114 +652,6 @@ static EVENT_HANDLER(WINDOW_TITLE_CHANGED)
     event_signal_push(SIGNAL_WINDOW_TITLE_CHANGED, window);
 }
 
-static EVENT_HANDLER(SLS_WINDOW_MOVED)
-{
-    uint32_t window_id = (uint32_t)(intptr_t) context;
-    struct window *window = window_manager_find_window(&g_window_manager, window_id);
-    if (!window) return;
-
-    if (!__sync_bool_compare_and_swap(&window->id_ptr, &window->id, &window->id)) {
-        debug("%s: %d has been marked invalid by the system, ignoring event..\n", __FUNCTION__, window_id);
-        return;
-    }
-
-    debug("%s: %s %d\n", __FUNCTION__, window->application->name, window->id);
-
-    struct border *border = &window->border;
-    if (border->id && border_should_order_in(window)) {
-        CGRect frame = {};
-        SLSGetWindowBounds(g_connection, window_id, &frame);
-        border_move(window, frame);
-    }
-}
-
-static EVENT_HANDLER(SLS_WINDOW_RESIZED)
-{
-    uint32_t window_id = (uint32_t)(intptr_t) context;
-    struct window *window = window_manager_find_window(&g_window_manager, window_id);
-    if (!window) return;
-
-    if (!__sync_bool_compare_and_swap(&window->id_ptr, &window->id, &window->id)) {
-        debug("%s: %d has been marked invalid by the system, ignoring event..\n", __FUNCTION__, window_id);
-        return;
-    }
-
-    debug("%s: %s %d\n", __FUNCTION__, window->application->name, window->id);
-
-    struct border *border = &window->border;
-    if (border->id && border_should_order_in(window)) {
-        CGRect frame = {};
-        SLSGetWindowBounds(g_connection, window_id, &frame);
-        border_resize(window, frame);
-    }
-}
-
-static EVENT_HANDLER(SLS_WINDOW_ORDER_CHANGED)
-{
-    if (g_mission_control_active) return;
-
-    uint32_t window_id = (uint32_t)(intptr_t) context;
-    struct window *window = window_manager_find_window(&g_window_manager, window_id);
-    if (!window) return;
-
-    if (!__sync_bool_compare_and_swap(&window->id_ptr, &window->id, &window->id)) {
-        debug("%s: %d has been marked invalid by the system, ignoring event..\n", __FUNCTION__, window_id);
-        return;
-    }
-
-    debug("%s: %s %d\n", __FUNCTION__, window->application->name, window->id);
-
-    struct border *border = &window->border;
-    if (border->id && border_should_order_in(window)) {
-        int window_level = 0;
-        SLSGetWindowLevel(g_connection, window_id, &window_level);
-        SLSSetWindowLevel(g_connection, border->id, window_level);
-        SLSOrderWindow(g_connection, border->id, -1, window_id);
-    }
-}
-
-static EVENT_HANDLER(SLS_WINDOW_IS_VISIBLE)
-{
-    if (g_mission_control_active) return;
-
-    uint32_t window_id = (uint32_t)(intptr_t) context;
-    struct window *window = window_manager_find_window(&g_window_manager, window_id);
-    if (!window) return;
-
-    if (!__sync_bool_compare_and_swap(&window->id_ptr, &window->id, &window->id)) {
-        debug("%s: %d has been marked invalid by the system, ignoring event..\n", __FUNCTION__, window_id);
-        return;
-    }
-
-    debug("%s: %s %d\n", __FUNCTION__, window->application->name, window->id);
-
-    struct border *border = &window->border;
-    if (border->id && border_should_order_in(window)) {
-        border_ensure_same_space(window);
-        SLSOrderWindow(g_connection, border->id, -1, window_id);
-    }
-}
-
-static EVENT_HANDLER(SLS_WINDOW_IS_INVISIBLE)
-{
-    uint32_t window_id = (uint32_t)(intptr_t) context;
-    struct window *window = window_manager_find_window(&g_window_manager, window_id);
-    if (!window) return;
-
-    if (!__sync_bool_compare_and_swap(&window->id_ptr, &window->id, &window->id)) {
-        debug("%s: %d has been marked invalid by the system, ignoring event..\n", __FUNCTION__, window_id);
-        return;
-    }
-
-    debug("%s: %s %d\n", __FUNCTION__, window->application->name, window->id);
-
-    struct border *border = &window->border;
-    if (border->id && border_should_order_in(window)) {
-        SLSOrderWindow(g_connection, border->id, 0, 0);
-        border_ensure_same_space(window);
-    }
-}
-
 static EVENT_HANDLER(SLS_SPACE_ADD_WINDOW)
 {
     uint32_t window_id = (uint32_t) param1;
@@ -837,6 +690,7 @@ static EVENT_HANDLER(SLS_SPACE_REMOVE_WINDOW)
 
     struct view *view = window_manager_find_managed_window(&g_window_manager, window);
     if (view) {
+        scripting_addition_set_layer(window->id, LAYER_NORMAL);
         struct window_node *node = view_remove_window_node(view, window);
         window_manager_remove_managed_window(&g_window_manager, window->id);
 
@@ -1211,8 +1065,8 @@ static EVENT_HANDLER(MOUSE_MOVED)
                     struct window *sub_window = window_manager_find_window(&g_window_manager, wid);
                     if (!sub_window) continue;
 
-                    if (!window_check_flag(sub_window, WINDOW_FLOAT)) continue;
-                    if (window_is_topmost(sub_window))                continue;
+                    if (!window_check_flag(sub_window, WINDOW_FLOAT))               continue;
+                    if (window_level(sub_window->id) != g_layer_below_window_level) continue;
 
                     if (CGRectContainsRect(window->frame, sub_window->frame)) {
                         occludes_window = true;
@@ -1245,8 +1099,6 @@ static EVENT_HANDLER(MISSION_CONTROL_SHOW_ALL_WINDOWS)
     debug("%s:\n", __FUNCTION__);
     g_mission_control_active = 2;
 
-    border_hide_all();
-
     for (int i = 0; i < buf_len(g_window_manager.insert_feedback_windows); ++i) {
         uint32_t feedback_wid = g_window_manager.insert_feedback_windows[i];
         SLSOrderWindow(g_connection, feedback_wid, 0, 0);
@@ -1260,8 +1112,6 @@ static EVENT_HANDLER(MISSION_CONTROL_SHOW_FRONT_WINDOWS)
     debug("%s:\n", __FUNCTION__);
     g_mission_control_active = 3;
 
-    border_hide_all();
-
     for (int i = 0; i < buf_len(g_window_manager.insert_feedback_windows); ++i) {
         uint32_t feedback_wid = g_window_manager.insert_feedback_windows[i];
         SLSOrderWindow(g_connection, feedback_wid, 0, 0);
@@ -1275,8 +1125,6 @@ static EVENT_HANDLER(MISSION_CONTROL_SHOW_DESKTOP)
     debug("%s:\n", __FUNCTION__);
     g_mission_control_active = 4;
 
-    border_hide_all();
-
     for (int i = 0; i < buf_len(g_window_manager.insert_feedback_windows); ++i) {
         uint32_t feedback_wid = g_window_manager.insert_feedback_windows[i];
         SLSOrderWindow(g_connection, feedback_wid, 0, 0);
@@ -1290,8 +1138,6 @@ static EVENT_HANDLER(MISSION_CONTROL_ENTER)
     debug("%s:\n", __FUNCTION__);
     g_mission_control_active = 1;
 
-    border_hide_all();
-
     for (int i = 0; i < buf_len(g_window_manager.insert_feedback_windows); ++i) {
         uint32_t feedback_wid = g_window_manager.insert_feedback_windows[i];
         SLSOrderWindow(g_connection, feedback_wid, 0, 0);
@@ -1351,14 +1197,12 @@ static EVENT_HANDLER(MISSION_CONTROL_EXIT)
 {
     debug("%s:\n", __FUNCTION__);
 
-    border_show_all();
-
     for (int i = 0; i < buf_len(g_window_manager.insert_feedback_windows); ++i) {
         uint32_t feedback_wid = g_window_manager.insert_feedback_windows[i];
         SLSOrderWindow(g_connection, feedback_wid, 1, 0);
     }
 
-    if (!workspace_is_macos_ventura()) {
+    if (!workspace_is_macos_ventura() && !workspace_is_macos_sonoma()) {
         if (g_mission_control_active == 1 || g_mission_control_active == 2) {
             window_manager_correct_for_mission_control_changes(&g_space_manager, &g_window_manager);
         }
@@ -1373,7 +1217,7 @@ static EVENT_HANDLER(DOCK_DID_RESTART)
 {
     debug("%s:\n", __FUNCTION__);
 
-    if (workspace_is_macos_monterey() || workspace_is_macos_ventura()) {
+    if (workspace_is_macos_monterey() || workspace_is_macos_ventura() || workspace_is_macos_sonoma()) {
         mission_control_unobserve();
         mission_control_observe();
     }
@@ -1392,11 +1236,6 @@ static EVENT_HANDLER(MENU_OPENED)
         ffm_value = g_window_manager.ffm_mode;
         g_window_manager.ffm_mode = FFM_DISABLED;
     }
-
-    if (g_window_manager.enable_window_topmost) {
-        uint32_t window_id = (uint32_t)(intptr_t) context;
-        scripting_addition_set_layer(window_id, LAYER_ABOVE);
-    }
 }
 
 static EVENT_HANDLER(MENU_CLOSED)
@@ -1429,7 +1268,6 @@ static EVENT_HANDLER(SYSTEM_WOKE)
     struct window *focused_window = window_manager_find_window(&g_window_manager, g_window_manager.focused_window_id);
     if (focused_window) {
         window_manager_set_window_opacity(&g_window_manager, focused_window, g_window_manager.active_window_opacity);
-        border_activate(focused_window);
         window_manager_center_mouse(&g_window_manager, focused_window);
     }
 }
