@@ -56,7 +56,6 @@
 #include "display.h"
 #include "space.h"
 #include "view.h"
-#include "border.h"
 #include "window.h"
 #include "process_manager.h"
 #include "application.h"
@@ -75,7 +74,6 @@
 #include "display.c"
 #include "space.c"
 #include "view.c"
-#include "border.c"
 #include "window.c"
 #include "process_manager.c"
 #include "application.c"
