@@ -124,6 +124,7 @@ void space_manager_untile_window(struct space_manager *sm, struct view *view, st
 {
     if (view->layout == VIEW_FLOAT) return;
 
+    scripting_addition_set_layer(window->id, LAYER_NORMAL);
     struct window_node *node = view_remove_window_node(view, window);
     if (!node) return;
 
@@ -385,6 +386,7 @@ struct view *space_manager_tile_window_on_space_with_insertion_point(struct spac
     struct view *view = space_manager_find_view(sm, sid);
     if (view->layout == VIEW_FLOAT) return view;
 
+    scripting_addition_set_layer(window->id, LAYER_BELOW);
     struct window_node *node = view_add_window_node_with_insertion_point(view, window, insertion_point);
     assert(node);
 
@@ -591,10 +593,7 @@ uint64_t space_manager_active_space(void)
 
 void space_manager_move_window_to_space(uint64_t sid, struct window *window)
 {
-    int window_count = window->border.id ? 2 : 1;
-    uint32_t window_list[2] = { window->id, window->border.id };
-
-    CFArrayRef window_list_ref = cfarray_of_cfnumbers(window_list, sizeof(uint32_t), window_count, kCFNumberSInt32Type);
+    CFArrayRef window_list_ref = cfarray_of_cfnumbers(&window->id, sizeof(uint32_t), 1, kCFNumberSInt32Type);
     SLSMoveWindowsToManagedSpace(g_connection, window_list_ref, sid);
     CFRelease(window_list_ref);
 }
