@@ -150,14 +150,6 @@ void window_manager_apply_rule_to_window(struct space_manager *sm, struct window
         window_manager_set_window_layer(window, rule->layer);
     }
 
-    if (rule->border == RULE_PROP_ON) {
-        window_rule_set_flag(window, WINDOW_RULE_BORDER);
-        border_create(window);
-    } else if (rule->border == RULE_PROP_OFF) {
-        window_rule_set_flag(window, WINDOW_RULE_BORDER);
-        border_destroy(window);
-    }
-
     if (in_range_ei(rule->alpha, 0.0f, 1.0f)) {
         window->opacity = rule->alpha;
         window_manager_set_opacity(wm, window, rule->alpha);
@@ -193,139 +185,6 @@ void window_manager_set_focus_follows_mouse(struct window_manager *wm, enum ffm_
     wm->ffm_mode = mode;
 }
 
-void window_manager_set_window_border_enabled(struct window_manager *wm, bool enabled)
-{
-    wm->enable_window_border = enabled;
-
-    for (int window_index = 0; window_index < wm->window.capacity; ++window_index) {
-        struct bucket *bucket = wm->window.buckets[window_index];
-        while (bucket) {
-            if (bucket->value) {
-                struct window *window = bucket->value;
-                if (!window_rule_check_flag(window, WINDOW_RULE_BORDER)) {
-                    if (enabled) {
-                        border_create(window);
-                    } else {
-                        border_destroy(window);
-                    }
-                }
-            }
-
-            bucket = bucket->next;
-        }
-    }
-
-    struct window *window = window_manager_focused_window(wm);
-    if (window) border_activate(window);
-}
-
-void window_manager_set_window_border_resolution(struct window_manager *wm, float resolution)
-{
-    wm->border_resolution = resolution;
-    for (int window_index = 0; window_index < wm->window.capacity; ++window_index) {
-        struct bucket *bucket = wm->window.buckets[window_index];
-        while (bucket) {
-            if (bucket->value) {
-                struct window *window = bucket->value;
-                if (window->border.id) {
-                    SLSSetWindowResolution(g_connection, window->border.id, resolution);
-                    border_redraw(window);
-                }
-            }
-
-            bucket = bucket->next;
-        }
-    }
-}
-
-void window_manager_set_window_border_blur(struct window_manager *wm, bool enabled)
-{
-    wm->border_blur = enabled;
-    for (int window_index = 0; window_index < wm->window.capacity; ++window_index) {
-        struct bucket *bucket = wm->window.buckets[window_index];
-        while (bucket) {
-            if (bucket->value) {
-                struct window *window = bucket->value;
-                if (window->border.id) {
-                    if (enabled) {
-                        SLSSetWindowBackgroundBlurRadiusStyle(g_connection, window->border.id, 24, 1);
-                        border_redraw(window);
-                    } else {
-                        SLSSetWindowBackgroundBlurRadiusStyle(g_connection, window->border.id, 0, 0);
-                        border_redraw(window);
-                    }
-                }
-            }
-
-            bucket = bucket->next;
-        }
-    }
-}
-
-void window_manager_set_window_border_width(struct window_manager *wm, int width)
-{
-    wm->border_width = width;
-    for (int window_index = 0; window_index < wm->window.capacity; ++window_index) {
-        struct bucket *bucket = wm->window.buckets[window_index];
-        while (bucket) {
-            if (bucket->value) {
-                struct window *window = bucket->value;
-                if (window->border.id) {
-                    CGContextSetLineWidth(window->border.context, width);
-                    border_redraw(window);
-                }
-            }
-
-            bucket = bucket->next;
-        }
-    }
-}
-
-void window_manager_set_window_border_radius(struct window_manager *wm, int radius)
-{
-    wm->border_radius = radius;
-    for (int window_index = 0; window_index < wm->window.capacity; ++window_index) {
-        struct bucket *bucket = wm->window.buckets[window_index];
-        while (bucket) {
-            if (bucket->value) {
-                struct window *window = bucket->value;
-                if (window->border.id) {
-                    if (window->border.path_ref) CGPathRelease(window->border.path_ref);
-                    window->border.path_ref = CGPathCreateWithRoundedRect(window->border.path, cgrect_clamp_x_radius(window->border.path, wm->border_radius), cgrect_clamp_y_radius(window->border.path, wm->border_radius), NULL);
-                    border_redraw(window);
-                }
-            }
-
-            bucket = bucket->next;
-        }
-    }
-}
-
-void window_manager_set_active_window_border_color(struct window_manager *wm, uint32_t color)
-{
-    wm->active_border_color = rgba_color_from_hex(color);
-    struct window *window = window_manager_focused_window(wm);
-    if (window) border_activate(window);
-}
-
-void window_manager_set_normal_window_border_color(struct window_manager *wm, uint32_t color)
-{
-    wm->normal_border_color = rgba_color_from_hex(color);
-    for (int window_index = 0; window_index < wm->window.capacity; ++window_index) {
-        struct bucket *bucket = wm->window.buckets[window_index];
-        while (bucket) {
-            if (bucket->value) {
-                struct window *window = bucket->value;
-                if (window->id != wm->focused_window_id) {
-                    border_deactivate(window);
-                }
-            }
-
-            bucket = bucket->next;
-        }
-    }
-}
-
 void window_manager_set_window_opacity_enabled(struct window_manager *wm, bool enabled)
 {
     wm->enable_window_opacity = enabled;
@@ -540,14 +399,14 @@ static void window_manager_create_window_proxy(int animation_connection, struct
     SLSSetWindowOpacity(animation_connection, proxy->id, 0);
     SLSSetWindowResolution(animation_connection, proxy->id, 2.0f);
     SLSSetWindowAlpha(animation_connection, proxy->id, 1.0f);
-    SLSSetWindowLevel(animation_connection, proxy->id, proxy->level);
+    SLSSetWindowLevel(animation_connection, proxy->id, g_layer_normal_window_level);
+    SLSSetWindowSubLevel(animation_connection, proxy->id, proxy->level);
     proxy->context = SLWindowContextCreate(animation_connection, proxy->id, 0);
 
     CGRect frame = { {0, 0}, proxy->frame.size };
     CGContextClearRect(proxy->context, frame);
     CGContextDrawImage(proxy->context, frame, (CGImageRef) CFArrayGetValueAtIndex(proxy->image, 0));
     CGContextFlush(proxy->context);
-
     CFRelease(frame_region);
 }
 
@@ -595,7 +454,7 @@ void *window_manager_animate_window_list_thread_proc(void *data)
         if (context->animation_list[i].skip) continue;
 
         table_remove(&g_window_manager.window_animations_table, &context->animation_list[i].wid);
-        scripting_addition_swap_window_proxy(context->animation_list[i].wid, context->animation_list[i].proxy.id, 1.0f, 0);
+        scripting_addition_swap_window_proxy_out(context->animation_list[i].wid, context->animation_list[i].proxy.id);
         window_manager_destroy_window_proxy(context->animation_connection, &context->animation_list[i].proxy);
     }
     SLSReenableUpdate(context->animation_connection);
@@ -620,18 +479,6 @@ void window_manager_animate_window_list_async(struct window_capture *window_list
     for (int i = 0; i < window_count; ++i) {
         struct window_capture *capture = &window_list[i];
 
-        if (capture->window->border.id) {
-            buf_push(context->animation_list, ((struct window_animation) {
-                .wid   = capture->window->border.id,
-                .x     = capture->x - g_window_manager.border_width,
-                .y     = capture->y - g_window_manager.border_width,
-                .w     = capture->w + g_window_manager.border_width * 2.0f,
-                .h     = capture->h + g_window_manager.border_width * 2.0f,
-                .proxy = {0},
-                .skip  = false
-            }));
-        }
-
         buf_push(context->animation_list, ((struct window_animation) {
             .wid   = capture->window->id,
             .x     = capture->x,
@@ -661,19 +508,26 @@ void window_manager_animate_window_list_async(struct window_capture *window_list
 
             window_manager_create_window_proxy(context->animation_connection, &context->animation_list[i].proxy);
 
-            CFTypeRef transaction = SLSTransactionCreate(context->animation_connection);
-            SLSTransactionOrderWindow(transaction, context->animation_list[i].proxy.id, 1, context->animation_list[i].wid);
-            SLSTransactionOrderWindow(transaction, existing_animation->proxy.id, 0, 0);
-            SLSTransactionCommit(transaction, 0);
-            CFRelease(transaction);
+            CFTypeRef transaction1 = SLSTransactionCreate(context->animation_connection);
+            CFTypeRef transaction2 = SLSTransactionCreate(context->animation_connection);
+
+            SLSTransactionOrderWindowGroup(transaction1, context->animation_list[i].proxy.id, 1, context->animation_list[i].wid);
+            SLSTransactionSetWindowSystemAlpha(transaction2, existing_animation->proxy.id, 0);
+
+            SLSTransactionCommit(transaction1, 1);
+            usleep(10000);
+            SLSTransactionCommit(transaction2, 1);
+
+            CFRelease(transaction1);
+            CFRelease(transaction2);
 
             window_manager_destroy_window_proxy(context->animation_connection, &existing_animation->proxy);
         } else {
-            SLSGetWindowLevel(context->animation_connection, context->animation_list[i].wid, &context->animation_list[i].proxy.level);
+            context->animation_list[i].proxy.level = window_level(context->animation_list[i].wid);
             SLSGetWindowBounds(context->animation_connection, context->animation_list[i].wid, &context->animation_list[i].proxy.frame);
             context->animation_list[i].proxy.image = SLSHWCaptureWindowList(context->animation_connection, &context->animation_list[i].wid, 1, (1 << 11) | (1 << 8));
             window_manager_create_window_proxy(context->animation_connection, &context->animation_list[i].proxy);
-            scripting_addition_swap_window_proxy(context->animation_list[i].wid, context->animation_list[i].proxy.id, 0.0f, 1);
+            scripting_addition_swap_window_proxy_in(context->animation_list[i].wid, context->animation_list[i].proxy.id);
         }
 
         table_add(&g_window_manager.window_animations_table, &context->animation_list[i].wid, &context->animation_list[i]);
@@ -683,7 +537,6 @@ void window_manager_animate_window_list_async(struct window_capture *window_list
 
     for (int i = 0; i < window_count; ++i) {
         window_manager_set_window_frame(window_list[i].window, window_list[i].x, window_list[i].y, window_list[i].w, window_list[i].h);
-        border_resize(window_list[i].window, window_ax_frame(window_list[i].window));
     }
 
     pthread_t thread;
@@ -842,14 +695,6 @@ bool window_manager_set_window_layer(struct window *window, int layer)
     return result;
 }
 
-void window_manager_make_window_topmost(struct window_manager *wm, struct window *window, bool topmost)
-{
-    if (!wm->enable_window_topmost) return;
-
-    int layer = topmost ? LAYER_ABOVE : LAYER_NORMAL;
-    window_manager_set_window_layer(window, layer);
-}
-
 void window_manager_purify_window(struct window_manager *wm, struct window *window)
 {
     int value;
@@ -1221,44 +1066,31 @@ static void window_manager_make_key_window(ProcessSerialNumber *window_psn, uint
     // annotated to flow to an application.
     //
 
-    //
-    // :Sonoma
-    //
-    // TODO(koekeishiya): Causes a crash on macos Sonoma.
-    // This causes autofocus to not work.
-    //
+    static uint8_t bytes[0xf8];
 
-    uint8_t bytes1[0xf8] = { [0x04] = 0xf8, [0x08] = 0x01, [0x3a] = 0x10 };
-    uint8_t bytes2[0xf8] = { [0x04] = 0xf8, [0x08] = 0x02, [0x3a] = 0x10 };
+    bytes[0x04] = 0xf8;
+    bytes[0x3a] = 0x10;
+    memcpy(bytes + 0x3c, &window_id, sizeof(uint32_t));
+    memset(bytes + 0x20, 0xff, 0x10);
 
-    memcpy(bytes1 + 0x3c, &window_id, sizeof(uint32_t));
-    memset(bytes1 + 0x20, 0xFF, 0x10);
+    bytes[0x08] = 0x01;
+    SLPSPostEventRecordTo(window_psn, bytes);
 
-    memcpy(bytes2 + 0x3c, &window_id, sizeof(uint32_t));
-    memset(bytes2 + 0x20, 0xFF, 0x10);
-
-    SLPSPostEventRecordTo(window_psn, bytes1);
-    SLPSPostEventRecordTo(window_psn, bytes2);
+    bytes[0x08] = 0x02;
+    SLPSPostEventRecordTo(window_psn, bytes);
 }
 
 void window_manager_focus_window_without_raise(ProcessSerialNumber *window_psn, uint32_t window_id)
 {
-    //
-    // :Sonoma
-    //
-    // TODO(koekeishiya): window_manager_make_key_window causes a crash on macos Sonoma.
-    // This causes autofocus to not work.
-    //
-
-    if (workspace_is_macos_sonoma()) {
-        debug("%s is not available on macOS Sonoma..\n", __FUNCTION__);
-        return;
-    }
-
     if (psn_equals(window_psn, &g_window_manager.focused_window_psn)) {
-        uint8_t bytes1[0xf8] = { [0x04] = 0xf8, [0x08] = 0x0d, [0x8a] = 0x02 };
-        memcpy(bytes1 + 0x3c, &g_window_manager.focused_window_id, sizeof(uint32_t));
-        SLPSPostEventRecordTo(&g_window_manager.focused_window_psn, bytes1);
+        static uint8_t bytes[0xf8];
+
+        bytes[0x04] = 0xf8;
+        bytes[0x08] = 0x0d;
+
+        bytes[0x8a] = 0x02;
+        memcpy(bytes + 0x3c, &g_window_manager.focused_window_id, sizeof(uint32_t));
+        SLPSPostEventRecordTo(&g_window_manager.focused_window_psn, bytes);
 
         //
         // @hack
@@ -1269,9 +1101,9 @@ void window_manager_focus_window_without_raise(ProcessSerialNumber *window_psn,
 
         usleep(10000);
 
-        uint8_t bytes2[0xf8] = { [0x04] = 0xf8, [0x08] = 0x0d, [0x8a] = 0x01 };
-        memcpy(bytes2 + 0x3c, &window_id, sizeof(uint32_t));
-        SLPSPostEventRecordTo(window_psn, bytes2);
+        bytes[0x8a] = 0x01;
+        memcpy(bytes + 0x3c, &window_id, sizeof(uint32_t));
+        SLPSPostEventRecordTo(window_psn, bytes);
     }
 
     _SLPSSetFrontProcessWithOptions(window_psn, window_id, kCPSUserGenerated);
@@ -1281,33 +1113,9 @@ void window_manager_focus_window_without_raise(ProcessSerialNumber *window_psn,
 void window_manager_focus_window_with_raise(ProcessSerialNumber *window_psn, uint32_t window_id, AXUIElementRef window_ref)
 {
 #if 1
-    //
-    // :Sonoma
-    //
-    // TODO(koekeishiya): window_manager_make_key_window causes a crash on macos Sonoma.
-    // This causes autofocus to not work, and will likely reintroduce issue #102.
-    //
-    //   How to reproduce the original problem:
-    //
-    //   Display 1: Open Terminal (A) and a Chrome window (B)
-    //   Display 2: Open a Chrome window (C)
-    //
-    //   Focus Chrome (B) on Display 1, and then focus Terminal (A) on Display 1.
-    //   Try to focus Chrome (C) on Display 2.
-    //
-    //   When using the accessibility API to focus the window, Chrome (B) on Display 1 would be focused.
-    //
-    //     -  https://github.com/koekeishiya/yabai/issues/102
-    //
-
-    if (workspace_is_macos_sonoma()) {
-        _SLPSSetFrontProcessWithOptions(window_psn, 0, kCPSNoWindows);
-        AXUIElementPerformAction(window_ref, kAXRaiseAction);
-    } else {
-        _SLPSSetFrontProcessWithOptions(window_psn, window_id, kCPSUserGenerated);
-        window_manager_make_key_window(window_psn, window_id);
-        AXUIElementPerformAction(window_ref, kAXRaiseAction);
-    }
+    _SLPSSetFrontProcessWithOptions(window_psn, window_id, kCPSUserGenerated);
+    window_manager_make_key_window(window_psn, window_id);
+    AXUIElementPerformAction(window_ref, kAXRaiseAction);
 #else
     scripting_addition_focus_window(window_id);
 #endif
@@ -1425,7 +1233,6 @@ struct window *window_manager_create_and_add_window(struct space_manager *sm, st
     if (window_is_unknown(window)) {
         debug("%s: ignoring AXUnknown window %s %d\n", __FUNCTION__, window->application->name, window->id);
         window_manager_remove_lost_focused_event(wm, window->id);
-        border_destroy(window);
         window_destroy(window);
         return NULL;
     }
@@ -1433,7 +1240,6 @@ struct window *window_manager_create_and_add_window(struct space_manager *sm, st
     if (window_is_popover(window)) {
         debug("%s: ignoring AXPopover window %s %d\n", __FUNCTION__, window->application->name, window->id);
         window_manager_remove_lost_focused_event(wm, window->id);
-        border_destroy(window);
         window_destroy(window);
         return NULL;
     }
@@ -1443,10 +1249,8 @@ struct window *window_manager_create_and_add_window(struct space_manager *sm, st
 
     if (!window_observe(window)) {
         debug("%s: could not observe %s %d\n", __FUNCTION__, window->application->name, window->id);
-        window_manager_make_window_topmost(wm, window, true);
         window_manager_remove_lost_focused_event(wm, window->id);
         window_unobserve(window);
-        border_destroy(window);
         window_destroy(window);
         return NULL;
     }
@@ -1460,11 +1264,6 @@ struct window *window_manager_create_and_add_window(struct space_manager *sm, st
     window_manager_add_window(wm, window);
     window_manager_apply_rules_to_window(sm, wm, window);
 
-    if ((wm->enable_window_border) &&
-        (!window_rule_check_flag(window, WINDOW_RULE_BORDER))) {
-        border_create(window);
-    }
-
     if ((!application->is_hidden) &&
         (!window_check_flag(window, WINDOW_MINIMIZE)) &&
         (!window_check_flag(window, WINDOW_FULLSCREEN)) &&
@@ -1476,7 +1275,6 @@ struct window *window_manager_create_and_add_window(struct space_manager *sm, st
                    (!window_can_move(window)) ||
                    (window_is_sticky(window)) ||
                    (!window_can_resize(window) && window_is_undersized(window))) {
-            window_manager_make_window_topmost(wm, window, true);
             window_set_flag(window, WINDOW_FLOAT);
         }
     }
@@ -1659,7 +1457,6 @@ enum window_op_error window_manager_stack_window(struct space_manager *sm, struc
         window_manager_purify_window(wm, b);
     } else if (window_check_flag(b, WINDOW_FLOAT)) {
         window_clear_flag(b, WINDOW_FLOAT);
-        window_manager_make_window_topmost(wm, b, false);
         if (window_check_flag(b, WINDOW_STICKY)) window_manager_make_window_sticky(sm, wm, b, false);
     }
 
@@ -1671,13 +1468,6 @@ enum window_op_error window_manager_stack_window(struct space_manager *sm, struc
     scripting_addition_order_window(b->id, 1, a_node->window_order[1]);
 
     struct area area = a_node->zoom ? a_node->zoom->area : a_node->area;
-    if (b->border.id) {
-        area.x += wm->border_width;
-        area.y += wm->border_width;
-        area.w -= wm->border_width * 2.0f;
-        area.h -= wm->border_width * 2.0f;
-    }
-
     window_manager_animate_window((struct window_capture) { b, area.x, area.y, area.w, area.h });
     return WINDOW_OP_ERROR_SUCCESS;
 }
@@ -1997,12 +1787,6 @@ enum window_op_error window_manager_apply_grid(struct space_manager *sm, struct
     return WINDOW_OP_ERROR_SUCCESS;
 }
 
-void window_manager_toggle_window_topmost(struct window *window)
-{
-    bool is_topmost = window_is_topmost(window);
-    window_manager_set_window_layer(window, is_topmost ? LAYER_NORMAL : LAYER_ABOVE);
-}
-
 void window_manager_make_window_floating(struct space_manager *sm, struct window_manager *wm, struct window *window, bool should_float)
 {
     if (should_float) {
@@ -2012,13 +1796,11 @@ void window_manager_make_window_floating(struct space_manager *sm, struct window
             window_manager_remove_managed_window(wm, window->id);
             window_manager_purify_window(wm, window);
         }
-        window_manager_make_window_topmost(wm, window, true);
         window_set_flag(window, WINDOW_FLOAT);
     } else {
         window_clear_flag(window, WINDOW_FLOAT);
 
         if (!window_check_flag(window, WINDOW_STICKY)) {
-            window_manager_make_window_topmost(wm, window, false);
             if ((window_manager_should_manage_window(window)) && (!window_manager_find_managed_window(wm, window))) {
                 struct view *view = space_manager_tile_window_on_space(sm, window, space_manager_active_space());
                 window_manager_add_managed_window(wm, window, view);
@@ -2037,18 +1819,13 @@ void window_manager_make_window_sticky(struct space_manager *sm, struct window_m
                 window_manager_remove_managed_window(wm, window->id);
                 window_manager_purify_window(wm, window);
             }
-            window_manager_make_window_topmost(wm, window, true);
-            if (window->border.id) border_ensure_same_space(window);
             window_set_flag(window, WINDOW_STICKY);
         }
     } else {
         if (scripting_addition_set_sticky(window->id, false)) {
-            if (window->border.id) border_ensure_same_space(window);
             window_clear_flag(window, WINDOW_STICKY);
 
             if (!window_check_flag(window, WINDOW_FLOAT)) {
-                window_manager_make_window_topmost(wm, window, false);
-
                 if ((window_manager_should_manage_window(window)) && (!window_manager_find_managed_window(wm, window))) {
                     struct view *view = space_manager_tile_window_on_space(sm, window, space_manager_active_space());
                     window_manager_add_managed_window(wm, window, view);
@@ -2072,7 +1849,7 @@ void window_manager_toggle_window_shadow(struct space_manager *sm, struct window
 
 void window_manager_wait_for_native_fullscreen_transition(struct window *window)
 {
-    if (workspace_is_macos_monterey() || workspace_is_macos_ventura()) {
+    if (workspace_is_macos_monterey() || workspace_is_macos_ventura() || workspace_is_macos_sonoma()) {
         while (!space_is_user(space_manager_active_space())) {
 
             //
@@ -2185,16 +1962,6 @@ void window_manager_toggle_window_pip(struct space_manager *sm, struct window_ma
     scripting_addition_scale_window(window->id, bounds.origin.x, bounds.origin.y, bounds.size.width, bounds.size.height);
 }
 
-void window_manager_toggle_window_border(struct window_manager *wm, struct window *window)
-{
-    if (window->border.id) {
-        border_destroy(window);
-    } else {
-        border_create(window);
-        if (window->id == wm->focused_window_id) border_activate(window);
-    }
-}
-
 static void window_manager_validate_windows_on_space(struct space_manager *sm, struct window_manager *wm, struct view *view, uint32_t *window_list, int window_count)
 {
     int view_window_count;
@@ -2225,6 +1992,7 @@ static void window_manager_validate_windows_on_space(struct space_manager *sm, s
             //
 
             view_remove_window_node(view, window);
+            scripting_addition_set_layer(window->id, LAYER_NORMAL);
             window_manager_remove_managed_window(wm, window->id);
             window_manager_purify_window(wm, window);
 
@@ -2253,6 +2021,7 @@ static void window_manager_check_for_windows_on_space(struct space_manager *sm,
             //
 
             view_remove_window_node(existing_view, window);
+            scripting_addition_set_layer(window->id, LAYER_NORMAL);
             window_manager_remove_managed_window(wm, window->id);
             window_manager_purify_window(wm, window);
             existing_view->is_dirty = true;
@@ -2271,6 +2040,7 @@ static void window_manager_check_for_windows_on_space(struct space_manager *sm,
             //
 
             view_add_window_node(view, window);
+            scripting_addition_set_layer(window->id, LAYER_BELOW);
             window_manager_add_managed_window(wm, window, view);
             view->is_dirty = true;
         }
@@ -2367,9 +2137,7 @@ void window_manager_init(struct window_manager *wm)
     wm->purify_mode = PURIFY_DISABLED;
     wm->window_origin_mode = WINDOW_ORIGIN_DEFAULT;
     wm->enable_mff = false;
-    wm->enable_window_border = false;
     wm->enable_window_opacity = false;
-    wm->enable_window_topmost = false;
     wm->active_window_opacity = 1.0f;
     wm->normal_window_opacity = 1.0f;
     wm->window_opacity_duration = 0.0f;
@@ -2377,12 +2145,6 @@ void window_manager_init(struct window_manager *wm)
     wm->window_animation_frame_rate = 120;
     wm->insert_feedback_windows = NULL;
     wm->insert_feedback_color = rgba_color_from_hex(0xffd75f5f);
-    wm->active_border_color = rgba_color_from_hex(0xff775759);
-    wm->normal_border_color = rgba_color_from_hex(0xff555555);
-    wm->border_resolution = 2.0f;
-    wm->border_blur = true;
-    wm->border_width = 4;
-    wm->border_radius = 12;
 
     table_init(&wm->application, 150, hash_wm, compare_wm);
     table_init(&wm->window, 150, hash_wm, compare_wm);
@@ -2423,6 +2185,5 @@ void window_manager_begin(struct space_manager *sm, struct window_manager *wm)
         wm->focused_window_id = window->id;
         wm->focused_window_psn = window->application->psn;
         window_manager_set_window_opacity(wm, window, wm->active_window_opacity);
-        border_activate(window);
     }
 }
