@@ -20,9 +20,9 @@
 #define HELP_OPT_LONG           "--help"
 #define HELP_OPT_SHRT           "-h"
 
-#define MAJOR  5
+#define MAJOR  6
 #define MINOR  0
-#define PATCH  8
+#define PATCH  0
 
 struct event_loop g_event_loop;
 void *g_workspace_context;
@@ -31,8 +31,9 @@ struct display_manager g_display_manager;
 struct space_manager g_space_manager;
 struct window_manager g_window_manager;
 struct mouse_state g_mouse_state;
-int g_normal_window_level;
-int g_floating_window_level;
+int g_layer_normal_window_level;
+int g_layer_below_window_level;
+int g_layer_above_window_level;
 int g_connection;
 pid_t g_pid;
 
@@ -176,8 +177,9 @@ static inline bool configure_settings_and_acquire_lock(void)
 
     g_pid = getpid();
     g_connection = SLSMainConnectionID();
-    g_normal_window_level   = CGWindowLevelForKey(LAYER_NORMAL);
-    g_floating_window_level = CGWindowLevelForKey(LAYER_ABOVE);
+    g_layer_normal_window_level = CGWindowLevelForKey(LAYER_NORMAL);
+    g_layer_below_window_level  = CGWindowLevelForKey(LAYER_BELOW);
+    g_layer_above_window_level  = CGWindowLevelForKey(LAYER_ABOVE);
 
     NSApplicationLoad();
     signal(SIGCHLD, SIG_IGN);
@@ -221,16 +223,6 @@ static CONNECTION_CALLBACK(connection_handler)
 
     if (type == 1204) {
         event_loop_post(&g_event_loop, MISSION_CONTROL_ENTER, NULL, 0);
-    } else if (type == 806) {
-        event_loop_post(&g_event_loop, SLS_WINDOW_MOVED, (void *) (intptr_t) (*(uint32_t *) data), 0);
-    } else if (type == 807) {
-        event_loop_post(&g_event_loop, SLS_WINDOW_RESIZED, (void *) (intptr_t) (* (uint32_t *) data), 0);
-    } else if (type == 808) {
-        event_loop_post(&g_event_loop, SLS_WINDOW_ORDER_CHANGED, (void *) (intptr_t) (* (uint32_t *) data), 0);
-    } else if (type == 815) {
-        event_loop_post(&g_event_loop, SLS_WINDOW_IS_VISIBLE, (void *) (intptr_t) (* (uint32_t *) data), 0);
-    } else if (type == 816) {
-        event_loop_post(&g_event_loop, SLS_WINDOW_IS_INVISIBLE, (void *) (intptr_t) (* (uint32_t *) data), 0);
     } else if (type == 1325) {
         event_loop_post(&g_event_loop, SLS_SPACE_ADD_WINDOW, (void *) (intptr_t) (* (uint64_t *) data), (int) (* (uint32_t *) (data + 8)));
     } else if (type == 1326) {
@@ -371,19 +363,13 @@ int main(int argc, char **argv)
         error("yabai: could not start mouse handler! abort..\n");
     }
 
-    if (workspace_is_macos_monterey() || workspace_is_macos_ventura()) {
+    if (workspace_is_macos_monterey() || workspace_is_macos_ventura() || workspace_is_macos_sonoma()) {
         mission_control_observe();
     } else {
         SLSRegisterConnectionNotifyProc(g_connection, connection_handler, 1204, NULL);
     }
 
-    SLSRegisterConnectionNotifyProc(g_connection, connection_handler, 806, NULL);
-    SLSRegisterConnectionNotifyProc(g_connection, connection_handler, 807, NULL);
-    SLSRegisterConnectionNotifyProc(g_connection, connection_handler, 808, NULL);
-    SLSRegisterConnectionNotifyProc(g_connection, connection_handler, 815, NULL);
-    SLSRegisterConnectionNotifyProc(g_connection, connection_handler, 816, NULL);
-
-    if (workspace_is_macos_ventura()) {
+    if (workspace_is_macos_ventura() || workspace_is_macos_sonoma()) {
         SLSRegisterConnectionNotifyProc(g_connection, connection_handler, 1325, NULL);
         SLSRegisterConnectionNotifyProc(g_connection, connection_handler, 1326, NULL);
         SLSRegisterConnectionNotifyProc(g_connection, connection_handler, 1327, NULL);
